window.Gleam.initSearch([{"doc":"nibble","title":"nibble","content":"# nibble\n\n[![Package Version](https://img.shields.io/hexpm/v/nibble)](https://hex.pm/packages/nibble)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/nibble/)\n\nA string parsing library heavily inspired by [`elm/parser`](https://github.com/elm/parser).\n\n## Quick start\n\n```gleam\nimport gleam/function\nimport nibble.{ Parser }\n\ntype Point {\n    Point(x: Int, y: Int)\n}\n\npub fn main () {\n    let parser = \n        nibble.succeed(function.curry2(Point))\n            |&gt; nibble.drop(nibble.grapheme(&quot;(&quot;))\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.keep(nibble.int())\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.drop(nibble.grapheme(&quot;,&quot;))\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.keep(nibble.int())\n            |&gt; nibble.drop(nibble.spaces())\n            |&gt; nibble.drop(nibble.grapheme(&quot;)&quot;))\n\n    assert Ok(point) = nibble.run(&quot;(1, 2)&quot;, parser)\n\n    point.x //=&gt; 1\n    point.y //=&gt; 2\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add nibble\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/nibble&gt;.\n","url":"index.html"},{"doc":"nibble","title":"nibble","content":"","url":"intro.html"},{"doc":"nibble","title":"nibble","content":"","url":"lexing.html"},{"doc":"nibble","title":"nibble","content":"","url":"parsing.html"},{"doc":"nibble","title":"nibble","content":"","url":"parse-contexts.html"},{"doc":"nibble","title":"nibble","content":"","url":"backtracking.html"},{"doc":"nibble","title":"nibble","content":"","url":"lexer-modes.html"},{"doc":"nibble","title":"nibble","content":"","url":"pratt-parsing.html"},{"doc":"nibble/lexer","title":"Error","content":"pub type Error {\n  NoMatchFound(row: Int, col: Int, lexeme: String)\n}\n\n\nNoMatchFound(row: Int, col: Int, lexeme: String)\n\n\nSynonyms:\nnibble/lexer.Error\nnibble/lexer Error","url":"nibble/lexer.html#Error"},{"doc":"nibble/lexer","title":"Lexer","content":"pub opaque type Lexer(a, mode)\n\n\n\nSynonyms:\nnibble/lexer.Lexer\nnibble/lexer Lexer","url":"nibble/lexer.html#Lexer"},{"doc":"nibble/lexer","title":"Match","content":"pub type Match(a, mode) {\n  Keep(a, mode)\n  Skip\n  Drop(mode)\n  NoMatch\n}\n\nKeep(a, mode)\n\n\nSkip\n\n\nDrop(mode)\n\n\nNoMatch\n\n\nSynonyms:\nnibble/lexer.Match\nnibble/lexer Match","url":"nibble/lexer.html#Match"},{"doc":"nibble/lexer","title":"Matcher","content":"pub opaque type Matcher(a, mode)\n\n\n\nSynonyms:\nnibble/lexer.Matcher\nnibble/lexer Matcher","url":"nibble/lexer.html#Matcher"},{"doc":"nibble/lexer","title":"Span","content":"pub type Span {\n  Span(\n    row_start: Int,\n    col_start: Int,\n    row_end: Int,\n    col_end: Int,\n  )\n}\n\n\nSpan(row_start: Int, col_start: Int, row_end: Int, col_end: Int)\n\n\nSynonyms:\nnibble/lexer.Span\nnibble/lexer Span","url":"nibble/lexer.html#Span"},{"doc":"nibble/lexer","title":"Token","content":"pub type Token(a) {\n  Token(span: Span, lexeme: String, value: a)\n}\n\n\nToken(span: Span, lexeme: String, value: a)\n\n\nSynonyms:\nnibble/lexer.Token\nnibble/lexer Token","url":"nibble/lexer.html#Token"},{"doc":"nibble/lexer","title":"comment","content":"pub fn comment(start: String, to_value: fn(String) -&gt; a) -&gt; Matcher(\n  a,\n  b,\n)\n\nSynonyms:\nnibble/lexer.comment\nnibble/lexer comment","url":"nibble/lexer.html#comment"},{"doc":"nibble/lexer","title":"custom","content":"pub fn custom(matchers: fn(a) -&gt; List(Matcher(b, a))) -&gt; Lexer(\n  b,\n  a,\n)\n\n\nSynonyms:\nnibble/lexer.custom\nnibble/lexer custom","url":"nibble/lexer.html#custom"},{"doc":"nibble/lexer","title":"custom_matcher","content":"pub fn custom_matcher(f: fn(a, String, String) -&gt; Match(b, a)) -&gt; Matcher(\n  b,\n  a,\n)\n\n\nSynonyms:\nnibble/lexer.custom_matcher\nnibble/lexer custom_matcher","url":"nibble/lexer.html#custom_matcher"},{"doc":"nibble/lexer","title":"drop","content":"pub fn drop(f: fn(String, String) -&gt; Bool) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.drop\nnibble/lexer drop","url":"nibble/lexer.html#drop"},{"doc":"nibble/lexer","title":"float","content":"pub fn float(to_value: fn(Float) -&gt; a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.float\nnibble/lexer float","url":"nibble/lexer.html#float"},{"doc":"nibble/lexer","title":"float_with_separator","content":"pub fn float_with_separator(separator: String, to_value: fn(Float) -&gt;\n    a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.float_with_separator\nnibble/lexer float_with_separator","url":"nibble/lexer.html#float_with_separator"},{"doc":"nibble/lexer","title":"identifier","content":"pub fn identifier(start: String, inner: String, reserved: Set(\n    String,\n  ), to_value: fn(String) -&gt; a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.identifier\nnibble/lexer identifier","url":"nibble/lexer.html#identifier"},{"doc":"nibble/lexer","title":"ignore","content":"pub fn ignore(matcher: Matcher(a, b)) -&gt; Matcher(c, b)\n\n\nSynonyms:\nnibble/lexer.ignore\nnibble/lexer ignore","url":"nibble/lexer.html#ignore"},{"doc":"nibble/lexer","title":"int","content":"pub fn int(to_value: fn(Int) -&gt; a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.int\nnibble/lexer int","url":"nibble/lexer.html#int"},{"doc":"nibble/lexer","title":"int_with_separator","content":"pub fn int_with_separator(separator: String, to_value: fn(Int) -&gt;\n    a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.int_with_separator\nnibble/lexer int_with_separator","url":"nibble/lexer.html#int_with_separator"},{"doc":"nibble/lexer","title":"keep","content":"pub fn keep(f: fn(String, String) -&gt; Result(a, Nil)) -&gt; Matcher(\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble/lexer.keep\nnibble/lexer keep","url":"nibble/lexer.html#keep"},{"doc":"nibble/lexer","title":"keyword","content":"pub fn keyword(str: String, breaker: String, value: a) -&gt; Matcher(\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble/lexer.keyword\nnibble/lexer keyword","url":"nibble/lexer.html#keyword"},{"doc":"nibble/lexer","title":"map","content":"pub fn map(matcher: Matcher(a, b), f: fn(a) -&gt; c) -&gt; Matcher(c, b)\n\n\nSynonyms:\nnibble/lexer.map\nnibble/lexer map","url":"nibble/lexer.html#map"},{"doc":"nibble/lexer","title":"number","content":"pub fn number(from_int: fn(Int) -&gt; a, from_float: fn(Float) -&gt; a) -&gt; Matcher(\n  a,\n  b,\n)\n\nSynonyms:\nnibble/lexer.number\nnibble/lexer number","url":"nibble/lexer.html#number"},{"doc":"nibble/lexer","title":"number_with_separator","content":"pub fn number_with_separator(separator: String, from_int: fn(Int) -&gt;\n    a, from_float: fn(Float) -&gt; a) -&gt; Matcher(a, b)\n\nSynonyms:\nnibble/lexer.number_with_separator\nnibble/lexer number_with_separator","url":"nibble/lexer.html#number_with_separator"},{"doc":"nibble/lexer","title":"run","content":"pub fn run(source: String, lexer: Lexer(a, Nil)) -&gt; Result(\n  List(Token(a)),\n  Error,\n)\n\n\nSynonyms:\nnibble/lexer.run\nnibble/lexer run","url":"nibble/lexer.html#run"},{"doc":"nibble/lexer","title":"run_custom","content":"pub fn run_custom(source: String, mode: a, lexer: Lexer(b, a)) -&gt; Result(\n  List(Token(b)),\n  Error,\n)\n\n\nSynonyms:\nnibble/lexer.run_custom\nnibble/lexer run_custom","url":"nibble/lexer.html#run_custom"},{"doc":"nibble/lexer","title":"simple","content":"pub fn simple(matchers: List(Matcher(a, Nil))) -&gt; Lexer(a, Nil)\n\n\nSynonyms:\nnibble/lexer.simple\nnibble/lexer simple","url":"nibble/lexer.html#simple"},{"doc":"nibble/lexer","title":"skip","content":"pub fn skip(matcher: Matcher(a, b)) -&gt; Matcher(c, b)\n\n\nSynonyms:\nnibble/lexer.skip\nnibble/lexer skip","url":"nibble/lexer.html#skip"},{"doc":"nibble/lexer","title":"spaces","content":"pub fn spaces(token: a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.spaces\nnibble/lexer spaces","url":"nibble/lexer.html#spaces"},{"doc":"nibble/lexer","title":"string","content":"pub fn string(char: String, to_value: fn(String) -&gt; a) -&gt; Matcher(\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble/lexer.string\nnibble/lexer string","url":"nibble/lexer.html#string"},{"doc":"nibble/lexer","title":"symbol","content":"pub fn symbol(str: String, breaker: String, value: a) -&gt; Matcher(\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble/lexer.symbol\nnibble/lexer symbol","url":"nibble/lexer.html#symbol"},{"doc":"nibble/lexer","title":"token","content":"pub fn token(str: String, value: a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.token\nnibble/lexer token","url":"nibble/lexer.html#token"},{"doc":"nibble/lexer","title":"transition","content":"pub fn transition(matcher: Matcher(a, b), f: fn(b) -&gt; b) -&gt; Matcher(\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble/lexer.transition\nnibble/lexer transition","url":"nibble/lexer.html#transition"},{"doc":"nibble/lexer","title":"try_identifier","content":"pub fn try_identifier(start: String, inner: String, reserved: Set(\n    String,\n  ), to_value: fn(String) -&gt; a) -&gt; Result(\n  Matcher(a, b),\n  CompileError,\n)\n\n\nSynonyms:\nnibble/lexer.try_identifier\nnibble/lexer try_identifier","url":"nibble/lexer.html#try_identifier"},{"doc":"nibble/lexer","title":"variable","content":"pub fn variable(reserved: Set(String), to_value: fn(String) -&gt; a) -&gt; Matcher(\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble/lexer.variable\nnibble/lexer variable","url":"nibble/lexer.html#variable"},{"doc":"nibble/lexer","title":"whitespace","content":"pub fn whitespace(token: a) -&gt; Matcher(a, b)\n\n\nSynonyms:\nnibble/lexer.whitespace\nnibble/lexer whitespace","url":"nibble/lexer.html#whitespace"},{"doc":"nibble/lexer","title":"nibble/lexer","content":"","url":"nibble/lexer.html"},{"doc":"nibble","title":"DeadEnd","content":"pub type DeadEnd(tok, ctx) {\n  DeadEnd(\n    pos: Span,\n    problem: Error(tok),\n    context: List(Located(ctx)),\n  )\n}\n A dead end represents a the point where a parser that had committed down a\n path failed. It contains the position of the failure, the [`Error`](#Error)\n describing the failure, and the context stack for any parsers that had run.\n\nDeadEnd(\n  pos: Span,\n  problem: Error(tok),\n  context: List(Located(ctx)),\n)\n\n\nSynonyms:\nnibble.DeadEnd\nnibble DeadEnd","url":"nibble.html#DeadEnd"},{"doc":"nibble","title":"Error","content":"pub type Error(tok) {\n  BadParser(String)\n  Custom(String)\n  EndOfInput\n  Expected(String, got: tok)\n  Unexpected(tok)\n}\n\n\n\n\nBadParser(String)\n\n\nCustom(String)\n\n\nEndOfInput\n\n\nExpected(String, got: tok)\n\n\nUnexpected(tok)\n\n\nSynonyms:\nnibble.Error\nnibble Error","url":"nibble.html#Error"},{"doc":"nibble","title":"Located","content":"pub type Located(ctx) {\n  Located(pos: Span, context: ctx)\n}\n\n\nLocated(pos: Span, context: ctx)\n\n\nSynonyms:\nnibble.Located\nnibble Located","url":"nibble.html#Located"},{"doc":"nibble","title":"Loop","content":"pub type Loop(a, state) {\n  Continue(state)\n  Break(a)\n}\n\n\nContinue(state)\n\n\nBreak(a)\n\n\nSynonyms:\nnibble.Loop\nnibble Loop","url":"nibble.html#Loop"},{"doc":"nibble","title":"Parser","content":"pub opaque type Parser(a, tok, ctx)\n The `Parser` type has three paramteres, let&#39;s take a look at each of them:\n\n \n Parser(a, tok, ctx)\n //     ^            (1)\n //        ^^^       (2)\n //             ^^^  (3)\n \n \n 1) `a` is the type of value that the parser knows how to produce. If you were\n   writing a parser for a programming language, this might be your expression\n   type.\n\n 2) `tok` is the type of tokens that the parser knows how to consume. You can\n   take a look at the [`Token`](./nibble/lexer#Token) type for a bit more info,\n   but note that it&#39;s not necessary for the token stream to come from nibble&#39;s\n   lexer.\n\n 3) `ctx` is used to make error reporting nicer. You can place a parser into a\n   custom context. When the parser runs the context gets pushed into a stack.\n   If the parser fails you can see the context stack in the error message,\n   which can make error reporting and debugging much easier!\n\n\nSynonyms:\nnibble.Parser\nnibble Parser","url":"nibble.html#Parser"},{"doc":"nibble","title":"any","content":"pub fn any() -&gt; Parser(a, a, b)\n\n\nSynonyms:\nnibble.any\nnibble any","url":"nibble.html#any"},{"doc":"nibble","title":"backtrackable","content":"pub fn backtrackable(parser: Parser(a, b, c)) -&gt; Parser(a, b, c)\n\n\nSynonyms:\nnibble.backtrackable\nnibble backtrackable","url":"nibble.html#backtrackable"},{"doc":"nibble","title":"commit","content":"pub fn commit(to a: a) -&gt; Parser(a, b, c)\n\n\nSynonyms:\nnibble.commit\nnibble commit","url":"nibble.html#commit"},{"doc":"nibble","title":"do","content":"pub fn do(parser: Parser(a, b, c), f: fn(a) -&gt; Parser(d, b, c)) -&gt; Parser(\n  d,\n  b,\n  c,\n)\n\n\nSynonyms:\nnibble.do\nnibble do","url":"nibble.html#do"},{"doc":"nibble","title":"do_in","content":"pub fn do_in(context: a, parser: Parser(b, c, a), f: fn(b) -&gt;\n    Parser(d, c, a)) -&gt; Parser(d, c, a)\n\n\nSynonyms:\nnibble.do_in\nnibble do_in","url":"nibble.html#do_in"},{"doc":"nibble","title":"eof","content":"pub fn eof() -&gt; Parser(Nil, a, b)\n\n\nSynonyms:\nnibble.eof\nnibble eof","url":"nibble.html#eof"},{"doc":"nibble","title":"fail","content":"pub fn fail(message: String) -&gt; Parser(a, b, c)\n\n\nSynonyms:\nnibble.fail\nnibble fail","url":"nibble.html#fail"},{"doc":"nibble","title":"in","content":"pub fn in(parser: Parser(a, b, c), context: c) -&gt; Parser(a, b, c)\n \n\nSynonyms:\nnibble.in\nnibble in","url":"nibble.html#in"},{"doc":"nibble","title":"inspect","content":"pub fn inspect(parser: Parser(a, b, c), message: String) -&gt; Parser(\n  a,\n  b,\n  c,\n)\n Run the given parser and then inspect it&#39;s state. \nSynonyms:\nnibble.inspect\nnibble inspect","url":"nibble.html#inspect"},{"doc":"nibble","title":"lazy","content":"pub fn lazy(parser: fn() -&gt; Parser(a, b, c)) -&gt; Parser(a, b, c)\n\n\nSynonyms:\nnibble.lazy\nnibble lazy","url":"nibble.html#lazy"},{"doc":"nibble","title":"list","content":"pub fn list(parser: Parser(a, b, c), separator sep: Parser(\n    d,\n    b,\n    c,\n  )) -&gt; Parser(List(a), b, c)\n\n\nSynonyms:\nnibble.list\nnibble list","url":"nibble.html#list"},{"doc":"nibble","title":"loop","content":"pub fn loop(init: a, step: fn(a) -&gt; Parser(Loop(b, a), c, d)) -&gt; Parser(\n  b,\n  c,\n  d,\n)\n\n\nSynonyms:\nnibble.loop\nnibble loop","url":"nibble.html#loop"},{"doc":"nibble","title":"many","content":"pub fn many(parser: Parser(a, b, c)) -&gt; Parser(List(a), b, c)\n\n\nSynonyms:\nnibble.many\nnibble many","url":"nibble.html#many"},{"doc":"nibble","title":"many1","content":"pub fn many1(parser: Parser(a, b, c)) -&gt; Parser(List(a), b, c)\n\n\nSynonyms:\nnibble.many1\nnibble many1","url":"nibble.html#many1"},{"doc":"nibble","title":"map","content":"pub fn map(parser: Parser(a, b, c), f: fn(a) -&gt; d) -&gt; Parser(\n  d,\n  b,\n  c,\n)\n\n\nSynonyms:\nnibble.map\nnibble map","url":"nibble.html#map"},{"doc":"nibble","title":"one_of","content":"pub fn one_of(parsers: List(Parser(a, b, c))) -&gt; Parser(a, b, c)\n\n\nSynonyms:\nnibble.one_of\nnibble one_of","url":"nibble.html#one_of"},{"doc":"nibble","title":"optional","content":"pub fn optional(parser: Parser(a, b, c)) -&gt; Parser(\n  Option(a),\n  b,\n  c,\n)\n\n\nSynonyms:\nnibble.optional\nnibble optional","url":"nibble.html#optional"},{"doc":"nibble","title":"or","content":"pub fn or(parser: Parser(a, b, c), default: a) -&gt; Parser(a, b, c)\n\n\nSynonyms:\nnibble.or\nnibble or","url":"nibble.html#or"},{"doc":"nibble","title":"replace","content":"pub fn replace(parser: Parser(a, b, c), with b: d) -&gt; Parser(\n  d,\n  b,\n  c,\n)\n\n\nSynonyms:\nnibble.replace\nnibble replace","url":"nibble.html#replace"},{"doc":"nibble","title":"return","content":"pub fn return(a: a) -&gt; Parser(a, b, c)\n\n\nSynonyms:\nnibble.return\nnibble return","url":"nibble.html#return"},{"doc":"nibble","title":"run","content":"pub fn run(src: List(Token(a)), parser: Parser(b, a, c)) -&gt; Result(\n  b,\n  List(DeadEnd(a, c)),\n)\n\n\nSynonyms:\nnibble.run\nnibble run","url":"nibble.html#run"},{"doc":"nibble","title":"take_if","content":"pub fn take_if(expecting: String, predicate: fn(a) -&gt; Bool) -&gt; Parser(\n  a,\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble.take_if\nnibble take_if","url":"nibble.html#take_if"},{"doc":"nibble","title":"take_map","content":"pub fn take_map(expecting: String, f: fn(a) -&gt; Option(b)) -&gt; Parser(\n  b,\n  a,\n  c,\n)\n\n\nSynonyms:\nnibble.take_map\nnibble take_map","url":"nibble.html#take_map"},{"doc":"nibble","title":"take_map_while","content":"pub fn take_map_while(f: fn(a) -&gt; Option(b)) -&gt; Parser(\n  List(b),\n  a,\n  c,\n)\n\n\nSynonyms:\nnibble.take_map_while\nnibble take_map_while","url":"nibble.html#take_map_while"},{"doc":"nibble","title":"take_map_while1","content":"pub fn take_map_while1(expecting: String, f: fn(a) -&gt; Option(b)) -&gt; Parser(\n  List(b),\n  a,\n  c,\n)\n\nSynonyms:\nnibble.take_map_while1\nnibble take_map_while1","url":"nibble.html#take_map_while1"},{"doc":"nibble","title":"take_until","content":"pub fn take_until(predicate: fn(a) -&gt; Bool) -&gt; Parser(\n  List(a),\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble.take_until\nnibble take_until","url":"nibble.html#take_until"},{"doc":"nibble","title":"take_until1","content":"pub fn take_until1(expecting: String, predicate: fn(a) -&gt; Bool) -&gt; Parser(\n  List(a),\n  a,\n  b,\n)\n\n\nSynonyms:\nnibble.take_until1\nnibble take_until1","url":"nibble.html#take_until1"},{"doc":"nibble","title":"take_while","content":"pub fn take_while(predicate: fn(a) -&gt; Bool) -&gt; Parser(\n  List(a),\n  a,\n  b,\n)\n\n\n 💡 This parser can succeed without consuming any input (if the predicate\n immediately fails). You can end up with an infinite loop if you&#39;re not \n careful. Use [`take_while1`](#take_while1) if you want to guarantee you \n take at least one token. \n\nSynonyms:\nnibble.take_while\nnibble take_while","url":"nibble.html#take_while"},{"doc":"nibble","title":"take_while1","content":"pub fn take_while1(expecting: String, predicate: fn(a) -&gt; Bool) -&gt; Parser(\n  List(a),\n  a,\n  b,\n)\n\n\n 💡 If this parser succeeds, the list produced is guaranteed to be non-empty.\n `let assert` away!\n\nSynonyms:\nnibble.take_while1\nnibble take_while1","url":"nibble.html#take_while1"},{"doc":"nibble","title":"then","content":"pub fn then(parser: Parser(a, b, c), f: fn(a) -&gt; Parser(d, b, c)) -&gt; Parser(\n  d,\n  b,\n  c,\n)\n\n\nSynonyms:\nnibble.then\nnibble then","url":"nibble.html#then"},{"doc":"nibble","title":"token","content":"pub fn token(tok: a) -&gt; Parser(Nil, a, b)\n\n\nSynonyms:\nnibble.token\nnibble token","url":"nibble.html#token"},{"doc":"nibble","title":"nibble","content":"","url":"nibble.html"},{"doc":"nibble/pratt","title":"Config","content":"pub opaque type Config(a, tok, ctx)\n\n\nSynonyms:\nnibble/pratt.Config\nnibble/pratt Config","url":"nibble/pratt.html#Config"},{"doc":"nibble/pratt","title":"Operator","content":"pub opaque type Operator(a, tok, ctx)\n\n\nSynonyms:\nnibble/pratt.Operator\nnibble/pratt Operator","url":"nibble/pratt.html#Operator"},{"doc":"nibble/pratt","title":"expression","content":"pub fn expression(one_of first: List(\n    fn(Config(a, b, c)) -&gt; Parser(a, b, c),\n  ), and_then then: List(Operator(a, b, c)), dropping spaces: Parser(\n    Nil,\n    b,\n    c,\n  )) -&gt; Parser(a, b, c)\n\nSynonyms:\nnibble/pratt.expression\nnibble/pratt expression","url":"nibble/pratt.html#expression"},{"doc":"nibble/pratt","title":"infix_left","content":"pub fn infix_left(precedence: Int, operator: Parser(Nil, a, b), apply: fn(\n    c,\n    c,\n  ) -&gt; c) -&gt; Operator(c, a, b)\n\nSynonyms:\nnibble/pratt.infix_left\nnibble/pratt infix_left","url":"nibble/pratt.html#infix_left"},{"doc":"nibble/pratt","title":"infix_right","content":"pub fn infix_right(precedence: Int, operator: Parser(Nil, a, b), apply: fn(\n    c,\n    c,\n  ) -&gt; c) -&gt; Operator(c, a, b)\n\nSynonyms:\nnibble/pratt.infix_right\nnibble/pratt infix_right","url":"nibble/pratt.html#infix_right"},{"doc":"nibble/pratt","title":"postfix","content":"pub fn postfix(precedence: Int, operator: Parser(Nil, a, b), apply: fn(\n    c,\n  ) -&gt; c) -&gt; Operator(c, a, b)\n\nSynonyms:\nnibble/pratt.postfix\nnibble/pratt postfix","url":"nibble/pratt.html#postfix"},{"doc":"nibble/pratt","title":"prefix","content":"pub fn prefix(precedence: Int, operator: Parser(Nil, a, b), apply: fn(\n    c,\n  ) -&gt; c) -&gt; fn(Config(c, a, b)) -&gt; Parser(c, a, b)\n\nSynonyms:\nnibble/pratt.prefix\nnibble/pratt prefix","url":"nibble/pratt.html#prefix"},{"doc":"nibble/pratt","title":"sub_expression","content":"pub fn sub_expression(config: Config(a, b, c), precedence: Int) -&gt; Parser(\n  a,\n  b,\n  c,\n)\n\nSynonyms:\nnibble/pratt.sub_expression\nnibble/pratt sub_expression","url":"nibble/pratt.html#sub_expression"},{"doc":"nibble/pratt","title":"nibble/pratt","content":"","url":"nibble/pratt.html"},{"doc":"nibble/predicates","title":"is_digit","content":"pub fn is_digit(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_digit\nnibble/predicates is_digit","url":"nibble/predicates.html#is_digit"},{"doc":"nibble/predicates","title":"is_lower_ascii","content":"pub fn is_lower_ascii(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_lower_ascii\nnibble/predicates is_lower_ascii","url":"nibble/predicates.html#is_lower_ascii"},{"doc":"nibble/predicates","title":"is_upper_ascii","content":"pub fn is_upper_ascii(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_upper_ascii\nnibble/predicates is_upper_ascii","url":"nibble/predicates.html#is_upper_ascii"},{"doc":"nibble/predicates","title":"is_whitespace","content":"pub fn is_whitespace(grapheme: String) -&gt; Bool\n\nSynonyms:\nnibble/predicates.is_whitespace\nnibble/predicates is_whitespace","url":"nibble/predicates.html#is_whitespace"},{"doc":"nibble/predicates","title":"string","content":"pub fn string(str: String, predicate: fn(String) -&gt; Bool) -&gt; Bool\n\nSynonyms:\nnibble/predicates.string\nnibble/predicates string","url":"nibble/predicates.html#string"},{"doc":"nibble/predicates","title":"nibble/predicates","content":"","url":"nibble/predicates.html"}]);